@@ -31,17 +31,21 @@
  * ACVPProxy Generic Definitions
  **************************************************************************/
 static const struct def_algo acvpproxy[] = {
-	ACVPPROXY_SHA(ACVP_SHA1),
-	ACVPPROXY_SHA(ACVP_SHA224),
 	ACVPPROXY_SHA(ACVP_SHA256),
-	ACVPPROXY_SHA(ACVP_SHA384),
 	ACVPPROXY_SHA(ACVP_SHA512),
 
-	ACVPPROXY_HMAC(ACVP_HMACSHA1),
-	ACVPPROXY_HMAC(ACVP_HMACSHA2_224),
+	ACVPPROXY_SHA(ACVP_SHA3_224),
+	ACVPPROXY_SHA(ACVP_SHA3_256),
+	ACVPPROXY_SHA(ACVP_SHA3_384),
+	ACVPPROXY_SHA(ACVP_SHA3_512),
+
 	ACVPPROXY_HMAC(ACVP_HMACSHA2_256),
-	ACVPPROXY_HMAC(ACVP_HMACSHA2_384),
-	ACVPPROXY_HMAC(ACVP_HMACSHA2_512)
+	ACVPPROXY_HMAC(ACVP_HMACSHA2_512),
+
+	ACVPPROXY_HMAC(ACVP_HMACSHA3_224),
+	ACVPPROXY_HMAC(ACVP_HMACSHA3_256),
+	ACVPPROXY_HMAC(ACVP_HMACSHA3_384),
+	ACVPPROXY_HMAC(ACVP_HMACSHA3_512)
 };
 
 /**************************************************************************
