@@ -653,12 +653,19 @@ static const struct def_algo_rsa_sigver_gen openssl_rsa_sigver_gen = {
 		}							\
 	}
 
-//TODO wire up
 #define OPENSSL_SAFEPRIMES						\
 	GENERIC_SAFEPRIMES(DEF_ALG_SAFEPRIMES_KEYGENERATION,		\
 			   ACVP_DH_MODP_2048 | ACVP_DH_MODP_3072 |	\
 			   ACVP_DH_MODP_4096 | ACVP_DH_MODP_6144 |	\
-			   ACVP_DH_MODP_8192)
+			   ACVP_DH_MODP_8192 | ACVP_DH_FFDHE_2048 |	\
+			   ACVP_DH_FFDHE_3072 | ACVP_DH_FFDHE_4096 |	\
+			   ACVP_DH_FFDHE_6144 | ACVP_DH_FFDHE_8192),	\
+	GENERIC_SAFEPRIMES(DEF_ALG_SAFEPRIMES_KEYVERIFICATION,		\
+			   ACVP_DH_MODP_2048 | ACVP_DH_MODP_3072 |	\
+			   ACVP_DH_MODP_4096 | ACVP_DH_MODP_6144 |	\
+			   ACVP_DH_MODP_8192 | ACVP_DH_FFDHE_2048 |	\
+			   ACVP_DH_FFDHE_3072 | ACVP_DH_FFDHE_4096 |	\
+			   ACVP_DH_FFDHE_6144 | ACVP_DH_FFDHE_8192)
 
 /**************************************************************************
  * ECDH Definitions
@@ -784,6 +791,20 @@ static const struct def_algo_kas_ffc_nokdfnokc openssl_kas_ffc_nokdfnokc_fc = {
 	__OPENSSL_KAS_FFC(&openssl_kas_ffc_nokdfnokc_fb),		\
 	__OPENSSL_KAS_FFC(&openssl_kas_ffc_nokdfnokc_fc)
 
+/**************************************************************************
+ * SP800-56A REV3
+ **************************************************************************/
+#define OPENSSL_KAS_ECC_SSC_R3						\
+	GENERIC_KAS_ECC_SSC_R3(ACVP_NISTP224 | ACVP_NISTP256 |		\
+		       	       ACVP_NISTP384 | ACVP_NISTP521)
+
+#define OPENSSL_KAS_FFC_SSC_R3						\
+	GENERIC_KAS_FFC_SSC_R3(ACVP_DH_MODP_2048 | ACVP_DH_MODP_3072 |	\
+			       ACVP_DH_MODP_4096 | ACVP_DH_MODP_6144 |	\
+			       ACVP_DH_MODP_8192 | ACVP_DH_FFDHE_2048 |	\
+			       ACVP_DH_FFDHE_3072 | ACVP_DH_FFDHE_4096 |\
+			       ACVP_DH_FFDHE_6144 | ACVP_DH_FFDHE_8192)
+
 /**************************************************************************
  * TLS Definitions
  **************************************************************************/
@@ -809,6 +830,35 @@ static const struct def_algo_prereqs openssl_kdf_prereqs[] = {
 		}							\
 	}
 
+#define OPENSSL_TLS13_KDF						\
+	{								\
+	.type = DEF_ALG_TYPE_KDF_TLS13,					\
+	.algo.kdf_tls13 = {						\
+		DEF_PREREQS(openssl_kdf_prereqs),			\
+		.hashalg = ACVP_SHA256 | ACVP_SHA384 | ACVP_SHA512,	\
+		.running_mode = DEF_ALG_KDF_TLS13_MODE_DHE		\
+		}							\
+	}
+
+#define OPENSSL_HKDF							\
+	{								\
+	.type = DEF_ALG_TYPE_HKDF,					\
+	.algo.hkdf = {							\
+		DEF_PREREQS(openssl_kdf_prereqs),			\
+		.mac_salt_method = DEF_ALG_KAS_KDF_MAC_SALT_DEFAULT |	\
+				   DEF_ALG_KAS_KDF_MAC_SALT_RANDOM,	\
+		.fixed_info_pattern_type = {				\
+				DEF_ALG_KAS_KDF_FI_PATTERN_U_PARTY_INFO,\
+				DEF_ALG_KAS_KDF_FI_PATTERN_V_PARTY_INFO },\
+		.cipher_spec = {					\
+			.macalg = ACVP_SHA224 | ACVP_SHA256 |		\
+				  ACVP_SHA384 | ACVP_SHA512,		\
+			DEF_ALG_DOMAIN(.z, 224, 65336, 8),		\
+			.l = 2048,					\
+			}						\
+		}							\
+	}
+
 /**************************************************************************
  * SSH Definitions
  **************************************************************************/
@@ -997,6 +1047,8 @@ static const struct def_algo openssl_gcm [] = {
 
 static const struct def_algo openssl_ffcdh [] = {
 	OPENSSL_KAS_FFC,
+	OPENSSL_KAS_FFC_SSC_R3,
+	OPENSSL_SAFEPRIMES,
 };
 
 static const struct def_algo openssl_sha [] = {
@@ -1066,6 +1118,7 @@ static const struct def_algo openssl_sha [] = {
 	OPENSSL_KDF,
 	OPENSSL_KAS_ECC,
 	OPENSSL_KAS_ECC_CDH,
+	OPENSSL_KAS_ECC_SSC_R3,
 
 	OPENSSL_PBKDF(ACVP_SHA1 |
 		      ACVP_SHA224 | ACVP_SHA256 | ACVP_SHA384 | ACVP_SHA512),
@@ -1113,6 +1166,11 @@ static const struct def_algo openssl_neon [] = {
 	OPENSSL_HMAC(ACVP_HMACSHA2_256),
 };
 
+static const struct def_algo openssl_tls13 [] = {
+	//OPENSSL_TLS13_KDF,
+	OPENSSL_HKDF
+};
+
 /**************************************************************************
  * Register operation
  **************************************************************************/
@@ -1133,6 +1191,13 @@ static struct def_algo_map openssl_algo_map [] = {
 		.impl_name = "KBKDF",
 		.impl_description = "Generic C non-optimized KBKDF implementation"
 	}, {
+	/* OpenSSL TLS 1.3 implementation **********************/
+		SET_IMPLEMENTATION(openssl_tls13),
+		.algo_name = "OpenSSL",
+		.processor = "",
+		.impl_name = "TLS v1.3",
+		.impl_description = "TLS v1.3 implementation"
+	}, {
 	/* OpenSSL AESNI implementation ***************************************/
 		SET_IMPLEMENTATION(openssl_aes),
 		.algo_name = "OpenSSL",
@@ -1465,13 +1530,13 @@ static struct def_algo_map openssl_algo_map [] = {
 		.algo_name = "OpenSSL",
 		.processor = "S390",
 		.impl_name = "AESASM",
-		.impl_description = "CPACF AES implementation"
+		.impl_description = "Assembler AES implementation"
 	}, {
 		SET_IMPLEMENTATION(openssl_gcm),
 		.algo_name = "OpenSSL",
 		.processor = "S390",
 		.impl_name = "AESASM_ASM",
-		.impl_description = "CPACF AES using assembler GCM implementation"
+		.impl_description = "Assembler AES using GCM with assembler GHASH implementation"
 
 	},
 };
